==> java-string-similarity-0.14-sources.jar: info/debatty/java/stringsimilarity/ShingleBased.java <==
/*
 * The MIT License
 *
 * Copyright 2015 tibo.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package info.debatty.java.stringsimilarity;


/**
 * Abstract class for string similarities that rely on set operations (like 
 * cosine similarity or jaccard index). This abstract base class cares for
 * converting input strings into sets of n-grams (aka k-shingles).
 * 
 * @author Thibault Debatty
 */
abstract class ShingleBased {
    protected final int k;
    
    /**
     * 
     * @param k 
     */
    public ShingleBased(int k) {
        this.k = k;
    }
    
    /**
     * 
     */
    public ShingleBased() {
        this(3);
    }
    
    /**
     * Return k, the length of k-shingles (aka n-grams)
     * @return 
     */
    public int getK() {
        return k;
    }

}

==> java-string-similarity-0.18-sources.jar: info/debatty/java/stringsimilarity/ShingleBased.java <==
/*
 * The MIT License
 *
 * Copyright 2015 tibo.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package info.debatty.java.stringsimilarity;

import net.jcip.annotations.Immutable;

/**
 * Abstract class for string similarities that rely on set operations (like
 * cosine similarity or jaccard index). This abstract base class cares for
 * converting input strings into sets of n-grams (aka k-shingles).
 *
 * @author Thibault Debatty
 */
@Immutable
abstract class ShingleBased {
    private static final int DEFAULT_K = 3;

    private final int k;

    /**
     *
     * @param k
     */
    ShingleBased(final int k) {
        this.k = k;
    }

    /**
     *
     */
    ShingleBased() {
        this(DEFAULT_K);
    }

    /**
     * Return k, the length of k-shingles (aka n-grams).
     * @return
     */
    public int getK() {
        return k;
    }

}
